@@ -72,9 +72,10 @@ cod <- function(x) {
 #' @param x Fitted model of class \code{lm}, \code{glm}, \code{lmerMod}/\code{lme}
 #'            or \code{glmerMod}.
 #' @param n Optional, a \code{lmerMod} object, representing the fitted null-model
-#'          to \code{x} (unconditional model). If \code{n} is given, the pseudo-r-squared
-#'          for random intercept and random slope variances are computed (see Kwok et al. 2008;
-#'          see 'Examples' and 'Details').
+#'          (unconditional model) to \code{x}. If \code{n} is given, the pseudo-r-squared
+#'          for random intercept and random slope variances are computed
+#'          (\cite{Kwok et al. 2008}) as well as the Omega squared value
+#'          (\cite{Xu 2003}). See 'Examples' and 'Details'.
 #'
 #' @return \itemize{
 #'           \item For linear models, the r-squared and adjusted r-squared values.
@@ -83,33 +84,56 @@ cod <- function(x) {
 #'           \item For \code{glmerMod} objects, Tjur's coefficient of determination.
 #'         }
 #'
-#' @details If \code{n} is given, the Pseudo-R2 statistic is the proportion of
+#' @note If \code{n} is given, the Pseudo-R2 statistic is the proportion of
 #'          explained variance in the random effect after adding co-variates or
 #'          predictors to the model, or in short: the proportion of the explained
 #'          variance in the random effect of the full (conditional) model \code{x}
 #'          compared to the null (unconditional) model \code{n}.
+#'          \cr \cr
+#'          The Omega-squared statistics, if \code{n} is given, is 1 - the proportion
+#'          of the residual variance of the full model compared to the null model's
+#'          residual variance, or in short: the the proportion of the residual
+#'          variation explained by the covariates.
+#'          \cr \cr
+#'          The r-squared statistics for linear mixed models, if the unconditional
+#'          model is also specified (see \code{n}), is the difference of the total
+#'          variance of the null and full model divided by the total variance of
+#'          the null model.
+#'          \cr \cr
+#'          Alternative ways to assess the "goodness-of-fit" is to compare the ICC
+#'          of the null model with the ICC of the full model (see \code{\link{icc}}).
 #'
-#' @note For linear models, the r-squared and adjusted r-squared value is returned,
-#'         as provided by the \code{summary}-function.
-#'         \cr \cr
-#'         For linear mixed models, an r-squared approximation by computing the
-#'         correlation between the fitted and observed values, as suggested by
-#'         Byrnes (2008), is returned as well as the Omega-squared value as
-#'         suggested by Xu (2003), unless \code{n} is specified. If \code{n}
-#'         is given, pseudo r-squared measures based on the variances of random
-#'         intercept (tau 00, between-group-variance) and random slope (tau 11,
-#'         random-slope-variance) are returned.
-#'         \cr \cr
-#'         For generalized linear models, Cox & Snell's and Nagelkerke's
-#'         pseudo r-squared values are returned.
-#'         \cr \cr
-#'         For generalized linear mixed models, the coefficient of determination
-#'         as suggested by Tjur (2009) (see also \code{\link{cod}}).
+#' @details For linear models, the r-squared and adjusted r-squared value is returned,
+#'          as provided by the \code{summary}-function.
+#'          \cr \cr
+#'          For linear mixed models, an r-squared approximation by computing the
+#'          correlation between the fitted and observed values, as suggested by
+#'          \cite{Byrnes (2008)}, is returned as well as a simpliefied version of
+#'          the Omega-squared value (1 - (residual variance / response variance),
+#'          \cite{Xu (2003)}, \cite{Nakagawa, Schielzeth 2013}), unless \code{n}
+#'          is specified.
+#'          \cr \cr
+#'          If \code{n} is given, for linear mixed models pseudo r-squared measures based
+#'          on the variances of random intercept (tau 00, between-group-variance)
+#'          and random slope (tau 11, random-slope-variance), as well as the
+#'          r-squared statistics as proposed by \cite{Snijders and Bosker 2012} and
+#'          the Omega-squared value (1 - (residual variance full model / residual
+#'          variance null model)) as suggested by \cite{Xu (2003)} are returned.
+#'          \cr \cr
+#'          For generalized linear models, Cox & Snell's and Nagelkerke's
+#'          pseudo r-squared values are returned.
+#'          \cr \cr
+#'          For generalized linear mixed models, the coefficient of determination
+#'          as suggested by \cite{Tjur (2009)} (see also \code{\link{cod}}).
 #'
 #' @references \itemize{
 #'               \item \href{http://glmm.wikidot.com/faq}{DRAFT r-sig-mixed-models FAQ}
 #'               \item Byrnes, J. 2008. Re: Coefficient of determination (R^2) when using lme() (\url{https://stat.ethz.ch/pipermail/r-sig-mixed-models/2008q2/000713.html})
 #'               \item Kwok OM, Underhill AT, Berry JW, Luo W, Elliott TR, Yoon M. 2008. Analyzing Longitudinal Data with Multilevel Models: An Example with Individuals Living with Lower Extremity Intra-Articular Fractures. Rehabilitation Psychology 53(3): 370–86. \doi{10.1037/a0012765}
+#'               \item Nakagawa S, Schielzeth H. 2013. A general and simple method for obtaining R2 from generalized linear mixed-effects models. Methods in Ecology and Evolution, 4(2):133–142. \doi{10.1111/j.2041-210x.2012.00261.x}
+#'               \item Rabe-Hesketh S, Skrondal A. 2012. Multilevel and longitudinal modeling using Stata. 3rd ed. College Station, Tex: Stata Press Publication
+#'               \item Raudenbush SW, Bryk AS. 2002. Hierarchical linear models: applications and data analysis methods. 2nd ed. Thousand Oaks: Sage Publications
+#'               \item Snijders TAB, Bosker RJ. 2012. Multilevel analysis: an introduction to basic and advanced multilevel modeling. 2nd ed. Los Angeles: Sage
 #'               \item Xu, R. 2003. Measuring explained variation in linear mixed effects models. Statist. Med. 22:3527-3541. \doi{10.1002/sim.1572}
 #'               \item Tjur T. 2009. Coefficients of determination in logistic regression models - a new proposal: The coefficient of discrimination. The American Statistician, 63(4): 366-372
 #'             }
@@ -180,13 +204,21 @@ r2 <- function(x, n = NULL) {
       # tau.11 is the variance of the random slopes, i.e. how model predictors
       # affect the trajectory of subjects over time (for growth models)
       rsq1 <- (attr(tau_null, "tau.11") - attr(tau_full, "tau.11")) / attr(tau_null, "tau.11")
+      # get r2
+      rsq <- ((attr(tau_null, "tau.00") + attr(tau_null, "sigma_2")) -
+        (attr(tau_full, "tau.00") + attr(tau_full, "sigma_2"))) /
+        (attr(tau_null, "tau.00") + attr(tau_null, "sigma_2"))
+      # get omega-squared
+      osq <- 1 - ((attr(tau_full, "sigma_2") / attr(tau_null, "sigma_2")))
       # if model has no random slope, we need to set this value to NA
       if (is.null(rsq1) || sjmisc::is_empty(rsq1)) rsq1 <- NA
       # name vectors
       names(rsq0) <- "R2(tau-00)"
       names(rsq1) <- "R2(tau-11)"
+      names(rsq) <- "R2"
+      names(osq) <- "O2"
       # return results
-      return(structure(class = "sjstats_r2", list(r2_tau00 = rsq0, r2_tau11 = rsq1)))
+      return(structure(class = "sjstats_r2", list(r2_tau00 = rsq0, r2_tau11 = rsq1, r2 = rsq, o2 = osq)))
     } else {
       # compute "correlation"
       lmfit <-  lm(resp_val(x) ~ stats::fitted(x))
